#!/usr/bin/perl -w
use File::Basename;
#look at the ltrid's from making the figure and look for the expression of each using samtools.
my $bampath = $ARGV[0];
my $bamfile = basename($bampath, ".bowtie2.bam");
my $bamdir = $bamfile . "expression.d";
#check if the expression data has already been extracted and skip with a warning
if( -f "$bamdir/$bamfile.expression"){
    warn("Expression data already contained in $bamdir/$bamfile.expression, skipping\n");
    exit(0);
}
#make a directory to keep the intermediate files.
mkdir $bamdir;
#this file contains information on the output of BLAST and LTRharvest on the reference genome
#this includes the position of hits from BLAST and HMMER for protease and reverse transcriptase
#it does not include alt assemblys or low confidence classifications
#this does include classification assigned by RAxML
my $ltridfile = "../../ProteaseProject/Figures/ltrid_table/assign_ltrid_table_cytological_bands.sh.csv";
open LTRID, "<$ltridfile";
open EXPRESSIONOUT, ">$bamdir/$bamfile.expression";
#print the header for the expression file
print EXPRESSIONOUT "#filename,mappingCount,FPKB\n";
while(<LTRID>){
    #for each ltrid entry, run samtools to check in on it
    chomp;
    my @values = split(/,/,$_);
    if($values[1] eq 'ltrid'){
        #it was an ltr, so process it
        #figure out which chromosome it is from
        my $chr = $values[2];
        my $start = $values[3];
        my $end = $values[4];
        #calculate length to normalize expression later
        my $kiloBases = ($end - $start + 1)/1000;
        #run samtools and print the total
        print "chr$chr:$start-$end\n";
        my $ofn = "chr$chr-$start-$end.txt";
        system "samtools view $bampath chr$chr:$start-$end > $bamdir/$ofn";
        open SAM, "<$bamdir/$ofn";
        open SAMOUT, ">$bamdir/$ofn.sam";
        #keep track of lines
        my $expressionLines = 0;
        while(<SAM>){
            #this filters out lines with MAPQ score of 0.
            #these scores were produced by bowtie2, which appears to have a max score of 42.
            my @samFields = split(/\t/,$_);
            print SAMOUT $_ if $samFields[4] > 0;
            $expressionLines++ if $samFields[4] > 0;
        }
        #calculate normalized expression
        my $fragmentsPerKiloBase = $expressionLines / $kiloBases;
        close SAM;
        close SAMOUT;
        print EXPRESSIONOUT "$ofn,$expressionLines,$fragmentsPerKiloBase\n";
    }
#this is the head -n 10 of the file LTRID
#key,id,chromosome,start,end,other
#1,ltrid,1,13012447,13021923,42,1p36.21
#1,RVT_1,1,13017251,13017752,42,1p36.21
#1,RT,1,13017252,,42,1p36.21
#1,PR,1,13018098,,42,1p36.21
#1,RVP,1,13018100,13018397,42,1p36.21
#2,ltrid,1,13207037,13216513,47,1p36.21
#2,PR,1,13210548,,47,1p36.21
#2,RVP,1,13210563,13210860,47,1p36.21
#2,RT,1,13211187,,47,1p36.21
}
close LTRID;
close EXPRESSIONOUT;
