#!/usr/bin/perl -w
#This script checks the BAM files to see if they contain any expression data from chromosome X and Y
#XIST is the gene that inactivates the extra X chromosome in female humans
#It's located at chrX:73820651-73852753
#open the logfile whence the CSV info will be written. It has no header.
open LOG, ">../data/$0.csv";
#this is the external harddrive which contains the very large BAM files.
#You will need to get these yourself or change this path if you're not me.
#maybe ask me and I still have them, otherwise you'll probably have to make them again.
chdir "/media/matthew/newback/bamdata";
opendir DIR, "." or die("couldn't open the current working directory\n");
#find all the bam files in the directory. They were made by bowtie2
my @bamfiles = grep { /.+\.bowtie2\.bam$/ } readdir DIR;
#It wouldn't make sense for there to be a 0 length array of files!
die("no BAM files.\n") unless scalar @bamfiles;
closedir DIR;
#get the expression data for each BAM
foreach my $bamfile (@bamfiles){
    #an earlier version of this wanted to just compare the ratio of genes expressed on X and Y.
    #as it turns out, a lot of the female transcripts map to Y.
    #I don't know why this is, but it's interesting. At least it prooves that the mapping is inaccurate!
    #These next two lines just read the entire chromosome. Coords based off GRCh38
    #each read returns one line, which is why counting with wc -l gives expression
    my $chryexpression = `samtools view $bamfile chrY:1-57227415|wc -l`;
    my $chrxexpression = `samtools view $bamfile chrX:1-156040895|wc -l`;
    #this reads XIST
    my $xist = `samtools view $bamfile chrX:73820651-73852753 | wc -l`;
    #I want to print my own newlines later, so kill the included ones now
    chomp $chryexpression;
    chomp $chrxexpression;
    #we need the accession # rather than the filename to merge with bamstats after this
    #the accessions look ugly with some in lowercase, so I uc them
    #this turns out to be a bad idea since bamstats has them lowercase
    #and the filenames are lowercase
    #it looks better though, even if I had to kludge reading bamstats into R after this ¯\_(ツ)_/¯
    my $accession = $bamfile;
    $accession =~ s/\.bowtie2\.bam//;
    $accession = uc $accession;
    #print the expression to the CSV file and to the screen
    print "$accession,chrY,$chryexpression\n$accession,chrX,$chrxexpression\n";
    #I was monitoring the ratio originally, which is how I found out it was a bad plan later.
    printf "ratio: %3f\n", $chryexpression/$chrxexpression;
    print LOG "$accession,chrY,$chryexpression\n$accession,chrX,$chrxexpression\n";
    print LOG "$accession,xist,$xist\n";
}
#close the log file and go home (to R to actually graph this out)
close LOG;
